Index: branches/eam_branches/ipp-20130904/psphot/src/psphotMergeSources.c
===================================================================
--- branches/eam_branches/ipp-20130904/psphot/src/psphotMergeSources.c	(revision 36298)
+++ branches/eam_branches/ipp-20130904/psphot/src/psphotMergeSources.c	(revision 36299)
@@ -129,4 +129,5 @@
         extCFF = psMetadataLookupPtr (NULL, readoutCFF->analysis, "PSPHOT.DETECTIONS");
         if (extCFF) {
+            psF32 exptime = psMetadataLookupF32(NULL, readout->parent->concepts, "CELL.EXPOSURE");
             for (int i = 0; i < extCFF->allSources->n; i++) {
                 pmSource *source = extCFF->allSources->data[i];
@@ -136,5 +137,9 @@
                 source->mode |= PM_SOURCE_MODE_EXTERNAL;
 
-		// source->peak->detValue,rawFlux,smoothFlux all set to input flux value
+		// source->peak->detValue,rawFlux,smoothFlux all set to input flux value which is scaled
+                // to 1 second exposure time. Scale to this image's exposure.
+                source->peak->rawFlux    *= exptime;
+                source->peak->smoothFlux *= exptime;
+                source->peak->detValue   *= exptime;
 		// source->peak->xf,yf, moments->Mx,My all set to input position
 
